@@ -8,23 +8,23 @@ COMMANDS:
                 labels.
     collect     Walk a directory, tag its Python files and make a JSON
                 database of the results.
-    recommend   Read and execute a pipeline of commands and report the
-                learning costs.
+    recommend   Read and execute a pipeline of commands and report the learning
+                costs.
 Type 'paroxython COMMAND --help' for more information on a specific command.
 
 DESCRIPTION:
-    Paroxython is an open-source tool which automatically finds and tags
-    algorithmic features (such as assignments, nested loops, tail-recursive
-    functions, etc.) in a collection of small Python programs, typically
-    gathered for educational purposes (e.g., examples, patterns, exercise
-    corrections). Each tag consists in a free-form label associated with its
-    spanning lines. These labels are then mapped onto a knowledge taxonomy
-    designed by the teacher with basic order constraints in mind (e.g., the
-    fact that the introduction of the concept of early exit must come after
-    that of loop, which itself requires that of control flow, is expressed with
-    the following taxon: flow/loop/exit/early). Source-codes, labels and taxons
-    are stored in a database, which can finally be filtered through a pipeline
-    of inclusion, exclusion and impartment commands on programs or taxons.
+    Paroxython is a command-line tool which finds and tags algorithmic features
+    (such as assignments, nested loops, tail-recursive functions, etc.) in a
+    collection of small Python programs, typically gathered for educational
+    purposes (e.g., examples, patterns, exercise corrections). Each tag consists
+    in a free-form label associated with its spanning lines. These labels are
+    then mapped onto a knowledge taxonomy designed by the teacher with basic
+    order constraints in mind (e.g., the fact that the introduction of the
+    concept of early exit must come after that of loop, which itself requires
+    that of control flow, is expressed with the following taxon:
+    flow/loop/exit/early). Source codes, labels and taxons are stored in a
+    database, which can finally be filtered through a pipeline of inclusion,
+    exclusion and impartment commands on programs or taxons.
 
 SEE ALSO:
     Repository  https://github.com/laowantong/paroxython
